@@ -1,4 +1,3 @@
-import logging
 from collections.abc import Callable
 from copy import copy
 from copy import deepcopy
@@ -22,6 +21,7 @@ from fractal_server.app.models.v2 import DatasetV2
 from fractal_server.app.models.v2 import HistoryImageCache
 from fractal_server.app.models.v2 import HistoryRun
 from fractal_server.app.models.v2 import HistoryUnit
+from fractal_server.app.models.v2 import JobV2
 from fractal_server.app.models.v2 import TaskGroupV2
 from fractal_server.app.models.v2 import WorkflowTaskV2
 from fractal_server.app.runner.exceptions import JobExecutionError
@@ -37,6 +37,7 @@ from fractal_server.images.status_tools import IMAGE_STATUS_KEY
 from fractal_server.images.tools import filter_image_list
 from fractal_server.images.tools import find_image_by_zarr_url
 from fractal_server.images.tools import merge_type_filters
+from fractal_server.logger import get_logger
 from fractal_server.types import AttributeFilters
 
 
@@ -102,7 +103,7 @@ def execute_tasks_v2(
     job_type_filters: dict[str, bool],
     job_attribute_filters: AttributeFilters,
 ) -> None:
-    logger = logging.getLogger(logger_name)
+    logger = get_logger(logger_name=logger_name)
 
     if not workflow_dir_local.exists():
         logger.warning(
@@ -193,6 +194,13 @@ def execute_tasks_v2(
             db.refresh(history_run)
             history_run_id = history_run.id
 
+            # Refresh `job.executor_error_log`, to avoid a spurious value left
+            # over from a previous task
+            job_db = db.get(JobV2, job_id)
+            job_db.executor_error_log = None
+            db.merge(job_db)
+            db.commit()
+
         # TASK EXECUTION (V2)
         try:
             if task.type in [
@@ -210,8 +218,8 @@ def execute_tasks_v2(
                     get_runner_config=get_runner_config,
                     history_run_id=history_run_id,
                     dataset_id=dataset.id,
-                    user_id=user_id,
                     task_type=task.type,
+                    user_id=user_id,
                 )
             elif task.type == TaskType.PARALLEL:
                 outcomes_dict, num_tasks = run_v2_task_parallel(
@@ -435,6 +443,12 @@ def execute_tasks_v2(
             db.commit()
             db.close()  # NOTE: this is needed, but the reason is unclear
 
+            # Store the SLURM error in the job database
+            job_db = db.get(JobV2, job_id)
+            job_db.executor_error_log = runner.executor_error_log
+            db.merge(job_db)
+            db.commit()
+
             # Create accounting record
             record = AccountingRecord(
                 user_id=user_id,
